http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java 
b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
index 6bd35a9..91f1536 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
@@ -19,7 +19,6 @@ package org.gridgain.grid.util.nio;
 
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -36,7 +35,7 @@ public interface GridNioFuture<R> {
      * returns operation result.
      *
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException Subclass of {@link 
GridException} thrown if the wait was interrupted.
      * @throws IgniteFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
      * @throws IgniteCheckedException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
@@ -50,7 +49,7 @@ public interface GridNioFuture<R> {
      *
      * @param timeout The maximum time to wait in milliseconds.
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException Subclass of {@link 
GridException} thrown if the wait was interrupted.
      * @throws IgniteFutureTimeoutException Subclass of {@link GridException} 
thrown if the wait was timed out.
      * @throws IgniteFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
      * @throws IgniteCheckedException If operation failed.
@@ -65,7 +64,7 @@ public interface GridNioFuture<R> {
      * @param timeout The maximum time to wait.
      * @param unit The time unit of the {@code timeout} argument.
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException Subclass of {@link 
GridException} thrown if the wait was interrupted.
      * @throws IgniteFutureTimeoutException Subclass of {@link GridException} 
thrown if the wait was timed out.
      * @throws IgniteFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
      * @throws IgniteCheckedException If operation failed.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java 
b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
index 38be056..dc6a424 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
@@ -19,7 +19,6 @@ package org.gridgain.grid.util.nio;
 
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.tostring.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
@@ -98,7 +97,7 @@ public class GridNioFutureImpl<R> extends 
AbstractQueuedSynchronizer implements
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
 
-            throw new GridInterruptedException(e);
+            throw new IgniteInterruptedException(e);
         }
     }
 
@@ -119,7 +118,7 @@ public class GridNioFutureImpl<R> extends 
AbstractQueuedSynchronizer implements
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
 
-            throw new GridInterruptedException("Got interrupted while waiting 
for future to complete.", e);
+            throw new IgniteInterruptedException("Got interrupted while 
waiting for future to complete.", e);
         }
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java 
b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
index b648c75..602261e 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
@@ -21,7 +21,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.thread.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.direct.*;
 import org.gridgain.grid.util.nio.ssl.*;
@@ -719,7 +718,7 @@ public class GridNioServer<T> {
                     try {
                         U.sleep(50);
                     }
-                    catch (GridInterruptedException e) {
+                    catch (IgniteInterruptedException e) {
                         throw new IOException("Thread has been interrupted.", 
e);
                     }
                 }
@@ -943,7 +942,7 @@ public class GridNioServer<T> {
                         try {
                             U.sleep(50);
                         }
-                        catch (GridInterruptedException e) {
+                        catch (IgniteInterruptedException e) {
                             throw new IOException("Thread has been 
interrupted.", e);
                         }
                     }
@@ -1077,7 +1076,7 @@ public class GridNioServer<T> {
                     try {
                         U.sleep(50);
                     }
-                    catch (GridInterruptedException e) {
+                    catch (IgniteInterruptedException e) {
                         throw new IOException("Thread has been interrupted.", 
e);
                     }
                 }
@@ -1125,7 +1124,7 @@ public class GridNioServer<T> {
         }
 
         /** {@inheritDoc} */
-        @Override protected void body() throws InterruptedException, 
GridInterruptedException {
+        @Override protected void body() throws InterruptedException, 
IgniteInterruptedException {
             try {
                 boolean reset = false;
                 while (!closed) {
@@ -1585,7 +1584,7 @@ public class GridNioServer<T> {
         }
 
         /** {@inheritDoc} */
-        @Override protected void body() throws InterruptedException, 
GridInterruptedException {
+        @Override protected void body() throws InterruptedException, 
IgniteInterruptedException {
             try {
                 boolean reset = false;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/main/java/org/gridgain/grid/util/typedef/PCE.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/typedef/PCE.java 
b/modules/core/src/main/java/org/gridgain/grid/util/typedef/PCE.java
index 208117e..cdccc73 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/typedef/PCE.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/typedef/PCE.java
@@ -19,7 +19,6 @@ package org.gridgain.grid.util.typedef;
 
 import org.apache.ignite.cache.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.cache.*;
 import org.gridgain.grid.util.lang.*;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java 
b/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java
index d194d6a..717fbd6 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java
@@ -18,7 +18,6 @@
 package org.gridgain.grid.util.worker;
 
 import org.apache.ignite.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.*;
 import org.jetbrains.annotations.*;
@@ -144,7 +143,7 @@ public abstract class GridWorker implements Runnable {
 
             body();
         }
-        catch (GridInterruptedException e) {
+        catch (IgniteInterruptedException e) {
             if (log.isDebugEnabled())
                 log.debug("Caught interrupted exception: " + e);
         }
@@ -193,9 +192,9 @@ public abstract class GridWorker implements Runnable {
      * The implementation should provide the execution body for this runnable.
      *
      * @throws InterruptedException Thrown in case of interruption.
-     * @throws GridInterruptedException If interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException If interrupted.
      */
-    protected abstract void body() throws InterruptedException, 
GridInterruptedException;
+    protected abstract void body() throws InterruptedException, 
IgniteInterruptedException;
 
     /**
      * Optional method that will be called after runnable is finished. Default

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/IgniteCacheEntryListenerEagerTtlDisabledTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/IgniteCacheEntryListenerEagerTtlDisabledTest.java
 
b/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/IgniteCacheEntryListenerEagerTtlDisabledTest.java
index 0912281..f681e59 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/IgniteCacheEntryListenerEagerTtlDisabledTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/IgniteCacheEntryListenerEagerTtlDisabledTest.java
@@ -17,7 +17,6 @@
 
 package org.apache.ignite.internal.processors.cache;
 
-import org.gridgain.grid.cache.*;
 
 /**
  * Tests expire events when {@link GridCacheConfiguration#isEagerTtl()} is 
disabled.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
index 7d78b78..de7f92b 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
@@ -21,7 +21,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.spi.communication.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.direct.*;
 import org.gridgain.grid.util.lang.*;
 import org.gridgain.grid.util.nio.*;
@@ -318,7 +317,7 @@ public abstract class 
GridTcpCommunicationSpiMultithreadedSelfTest extends GridS
                         
((TcpCommunicationSpi)spis.get(from.id())).onNodeLeft(to.id());
                     }
                 }
-                catch (GridInterruptedException ignored) {
+                catch (IgniteInterruptedException ignored) {
                     Thread.currentThread().interrupt();
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
index 611e7e3..4fd9f21 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
@@ -22,7 +22,6 @@ import org.apache.ignite.lang.*;
 import org.apache.ignite.streamer.index.hash.*;
 import org.apache.ignite.streamer.index.tree.*;
 import org.apache.ignite.streamer.window.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.testframework.junits.common.*;
@@ -320,7 +319,7 @@ public class GridStreamerIndexSelfTest extends 
GridCommonAbstractTest {
                                 U.sleep(50);
                         }
                     }
-                    catch (GridInterruptedException ignored) {
+                    catch (IgniteInterruptedException ignored) {
                         // No-op.
                     }
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
index 4b61291..113b328 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
@@ -28,7 +28,6 @@ import org.apache.ignite.marshaller.*;
 import org.apache.ignite.marshaller.optimized.*;
 import org.apache.ignite.resources.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.managers.communication.*;
 import org.apache.ignite.spi.communication.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.*;
@@ -146,7 +145,7 @@ public class GridJobMasterLeaveAwareSelfTest extends 
GridCommonAbstractTest {
                 try {
                     U.sleep(500);
                 }
-                catch (GridInterruptedException ignore) {
+                catch (IgniteInterruptedException ignore) {
                     // No-op.
                 }
 
@@ -763,7 +762,7 @@ public class GridJobMasterLeaveAwareSelfTest extends 
GridCommonAbstractTest {
                         try {
                             U.await(waitLatch);
                         }
-                        catch (GridInterruptedException ignore) {
+                        catch (IgniteInterruptedException ignore) {
                             // No-op.
                         }
                     }
@@ -798,9 +797,9 @@ public class GridJobMasterLeaveAwareSelfTest extends 
GridCommonAbstractTest {
         /**
          * Await for job execution response to come.
          *
-         * @throws GridInterruptedException If interrupted.
+         * @throws org.apache.ignite.IgniteInterruptedException If interrupted.
          */
-        private void awaitResponse() throws GridInterruptedException{
+        private void awaitResponse() throws IgniteInterruptedException {
             U.await(respLatch);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
index 24b6b27..dd138c0 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/managers/checkpoint/GridCheckpointManagerAbstractSelfTest.java
@@ -25,7 +25,6 @@ import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.mbean.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.apache.ignite.spi.checkpoint.cache.*;
 import org.apache.ignite.spi.checkpoint.jdbc.*;
@@ -748,9 +747,9 @@ public abstract class GridCheckpointManagerAbstractSelfTest 
extends GridCommonAb
      * Wrapper around {@link 
GridTestUtils#retryAssert(org.apache.ignite.IgniteLogger, int, long, 
GridAbsClosure)}.
      * For the given closure provides count of retries, configured by {@link 
#retries} attribute.
      * @param assertion Closure with assertion inside.
-     * @throws GridInterruptedException If was interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException If was interrupted.
      */
-    private static void assertWithRetries(GridAbsClosureX assertion) throws 
GridInterruptedException {
+    private static void assertWithRetries(GridAbsClosureX assertion) throws 
IgniteInterruptedException {
         GridTestUtils.retryAssert(null, retries, 5000, assertion);
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheGenericTestStore.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheGenericTestStore.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheGenericTestStore.java
index 0e463c9..e16fe7a 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheGenericTestStore.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheGenericTestStore.java
@@ -20,7 +20,6 @@ package org.gridgain.grid.kernal.processors.cache;
 import org.apache.ignite.*;
 import org.apache.ignite.cache.store.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 import javax.cache.*;
@@ -267,7 +266,7 @@ public class GridCacheGenericTestStore<K, V> extends 
CacheStore<K, V> {
             try {
                 U.sleep(operationDelay);
             }
-            catch(GridInterruptedException e) {
+            catch(IgniteInterruptedException e) {
                 throw new IgniteException(e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePartitionedAffinitySpreadTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePartitionedAffinitySpreadTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePartitionedAffinitySpreadTest.java
index 1ddb836..1abc66c 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePartitionedAffinitySpreadTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePartitionedAffinitySpreadTest.java
@@ -25,6 +25,8 @@ import org.gridgain.testframework.junits.common.*;
 
 import java.util.*;
 
+import static 
org.apache.ignite.cache.affinity.consistenthash.GridCacheConsistentHashAffinityFunction.*;
+
 /**
  *
  */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePreloadingEvictionsSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePreloadingEvictionsSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePreloadingEvictionsSelfTest.java
index 0adf941..1634767 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePreloadingEvictionsSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCachePreloadingEvictionsSelfTest.java
@@ -22,7 +22,6 @@ import org.apache.ignite.cache.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.*;
 import org.apache.ignite.spi.discovery.tcp.*;
@@ -185,10 +184,10 @@ public class GridCachePreloadingEvictionsSelfTest extends 
GridCommonAbstractTest
      * @param ignite1 Grid 1.
      * @param ignite2 Grid 2.
      * @param oldSize Old size, stable size should be .
-     * @throws GridInterruptedException If interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException If interrupted.
      */
     private void sleepUntilCashesEqualize(final Ignite ignite1, final Ignite 
ignite2, final int oldSize)
-        throws GridInterruptedException {
+        throws IgniteInterruptedException {
         info("Sleeping...");
 
         assertTrue(GridTestUtils.waitForCondition(new PA() {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheTestStore.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheTestStore.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheTestStore.java
index c783f6c..0bf7719 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheTestStore.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheTestStore.java
@@ -21,7 +21,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cache.store.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.transactions.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.processors.cache.transactions.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.typedef.internal.*;
@@ -307,7 +306,7 @@ public final class GridCacheTestStore extends 
CacheStore<Integer, String> {
             try {
                 U.sleep(operationDelay);
             }
-            catch (GridInterruptedException e) {
+            catch (IgniteInterruptedException e) {
                 throw new IgniteException(e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStorePartitionedMultiNodeSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStorePartitionedMultiNodeSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStorePartitionedMultiNodeSelfTest.java
index cc1c26e..c5cf579 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStorePartitionedMultiNodeSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/GridCacheWriteBehindStorePartitionedMultiNodeSelfTest.java
@@ -17,6 +17,7 @@
 
 package org.gridgain.grid.kernal.processors.cache;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.store.*;
@@ -182,9 +183,9 @@ public class 
GridCacheWriteBehindStorePartitionedMultiNodeSelfTest extends GridC
     }
 
     /**
-     * @throws GridInterruptedException If sleep was interrupted.
+     * @throws IgniteInterruptedException If sleep was interrupted.
      */
-    private void checkWrites() throws GridInterruptedException {
+    private void checkWrites() throws IgniteInterruptedException {
         U.sleep(WRITE_BEHIND_FLUSH_FREQ * 2);
 
         Collection<Integer> allKeys = new ArrayList<>(100);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueJoinedNodeSelfAbstractTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueJoinedNodeSelfAbstractTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueJoinedNodeSelfAbstractTest.java
index c5f4583..2c9b300 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueJoinedNodeSelfAbstractTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueJoinedNodeSelfAbstractTest.java
@@ -22,7 +22,6 @@ import org.apache.ignite.cache.datastructures.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
@@ -245,18 +244,18 @@ public abstract class 
GridCacheQueueJoinedNodeSelfAbstractTest extends GridCommo
         /**
          * Awaits for a given count of items to be taken.
          *
-         * @throws GridInterruptedException If interrupted.
+         * @throws org.apache.ignite.IgniteInterruptedException If interrupted.
          */
-        private void awaitItems() throws GridInterruptedException {
+        private void awaitItems() throws IgniteInterruptedException {
             U.await(takeLatch);
         }
 
         /**
          * Awaits for a given count of items to be taken.
          *
-         * @throws GridInterruptedException If interrupted.
+         * @throws org.apache.ignite.IgniteInterruptedException If interrupted.
          */
-        private void awaitDone() throws GridInterruptedException {
+        private void awaitDone() throws IgniteInterruptedException {
             U.await(doneLatch);
         }
 
@@ -281,7 +280,7 @@ public abstract class 
GridCacheQueueJoinedNodeSelfAbstractTest extends GridCommo
                 }
             }
             catch (IgniteException e) {
-                if (e.getCause() instanceof GridInterruptedException || 
e.getCause() instanceof InterruptedException)
+                if (e.getCause() instanceof IgniteInterruptedException || 
e.getCause() instanceof InterruptedException)
                     log.info("Cancelling job due to interruption: " + 
e.getMessage());
                 else
                     fail("Unexpected error: " + e);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridCacheDhtPreloadDelayedSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridCacheDhtPreloadDelayedSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridCacheDhtPreloadDelayedSelfTest.java
index 5844911..efb8782 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridCacheDhtPreloadDelayedSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridCacheDhtPreloadDelayedSelfTest.java
@@ -19,14 +19,12 @@ package 
org.gridgain.grid.kernal.processors.cache.distributed.dht;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
-import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.affinity.*;
 import org.apache.ignite.cache.affinity.consistenthash.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.dht.preloader.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.near.*;
@@ -415,7 +413,7 @@ public class GridCacheDhtPreloadDelayedSelfTest extends 
GridCommonAbstractTest {
      * @param caches Maps to compare.
      */
     private void checkMaps(final boolean strict, final 
GridDhtCacheAdapter<String, Integer>... caches)
-        throws GridInterruptedException {
+        throws IgniteInterruptedException {
         if (caches.length < 2)
             return;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridCacheAtomicInvalidPartitionHandlingSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridCacheAtomicInvalidPartitionHandlingSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridCacheAtomicInvalidPartitionHandlingSelfTest.java
index cf74679..57c68db 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridCacheAtomicInvalidPartitionHandlingSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/atomic/GridCacheAtomicInvalidPartitionHandlingSelfTest.java
@@ -17,6 +17,7 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed.dht.atomic;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.*;
 import org.apache.ignite.cluster.*;
@@ -304,7 +305,7 @@ public class 
GridCacheAtomicInvalidPartitionHandlingSelfTest extends GridCommonA
                 if (delayMessage((GridIoMessage)msg))
                     U.sleep(ThreadLocalRandom8.current().nextInt(250) + 1);
             }
-            catch (GridInterruptedException e) {
+            catch (IgniteInterruptedException e) {
                 throw new IgniteSpiException(e);
             }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/near/GridCachePartitionedAffinitySelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/near/GridCachePartitionedAffinitySelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/near/GridCachePartitionedAffinitySelfTest.java
index bedefa98..0a73414 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/near/GridCachePartitionedAffinitySelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/distributed/near/GridCachePartitionedAffinitySelfTest.java
@@ -39,6 +39,7 @@ import java.io.*;
 import java.util.*;
 import java.util.concurrent.atomic.*;
 
+import static 
org.apache.ignite.cache.affinity.consistenthash.GridCacheConsistentHashAffinityFunction.*;
 import static org.apache.ignite.events.IgniteEventType.*;
 import static org.apache.ignite.cache.GridCacheAtomicityMode.*;
 import static org.apache.ignite.cache.GridCacheMode.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/eviction/GridCacheEmptyEntriesAbstractSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/eviction/GridCacheEmptyEntriesAbstractSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/eviction/GridCacheEmptyEntriesAbstractSelfTest.java
index 49eccd8..90dbc64 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/eviction/GridCacheEmptyEntriesAbstractSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/eviction/GridCacheEmptyEntriesAbstractSelfTest.java
@@ -19,11 +19,9 @@ package org.gridgain.grid.kernal.processors.cache.eviction;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
-import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.store.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.transactions.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.cache.eviction.GridCacheEvictionPolicy;
 import org.apache.ignite.cache.eviction.fifo.GridCacheFifoEvictionPolicy;
 import org.apache.ignite.cache.store.CacheStore;
@@ -283,10 +281,10 @@ public abstract class 
GridCacheEmptyEntriesAbstractSelfTest extends GridCommonAb
      * Checks that cache is empty.
      *
      * @param cache Cache to check.
-     * @throws GridInterruptedException If interrupted while sleeping.
+     * @throws org.apache.ignite.IgniteInterruptedException If interrupted 
while sleeping.
      */
     @SuppressWarnings({"ErrorNotRethrown", "TypeMayBeWeakened"})
-    private void checkEmpty(GridCache<String, String> cache) throws 
GridInterruptedException {
+    private void checkEmpty(GridCache<String, String> cache) throws 
IgniteInterruptedException {
         for (int i = 0; i < 3; i++) {
             try {
                 assertTrue(cache.entrySet().toString(), 
cache.entrySet().isEmpty());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryAbstractSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryAbstractSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryAbstractSelfTest.java
index 130aa06..097c21d 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryAbstractSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/cache/query/continuous/GridCacheContinuousQueryAbstractSelfTest.java
@@ -19,7 +19,6 @@ package 
org.gridgain.grid.kernal.processors.cache.query.continuous;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
-import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.query.*;
 import org.apache.ignite.cache.store.*;
 import org.apache.ignite.cluster.*;
@@ -28,10 +27,10 @@ import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.marshaller.optimized.*;
 import org.gridgain.grid.kernal.*;
-import org.gridgain.grid.kernal.processors.continuous.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
+import org.gridgain.grid.kernal.processors.continuous.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
@@ -53,6 +52,7 @@ import static 
org.apache.ignite.cache.GridCacheDistributionMode.*;
 import static org.apache.ignite.cache.GridCacheMode.*;
 import static org.apache.ignite.cache.GridCachePreloadMode.*;
 import static org.apache.ignite.cache.GridCacheWriteSynchronizationMode.*;
+import static org.apache.ignite.cache.query.GridCacheQueryType.*;
 import static org.apache.ignite.events.IgniteEventType.*;
 
 /**
@@ -254,8 +254,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
             null
         );
 
-        q.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Object, Object>>>() {
-            @Override public boolean apply(UUID uuid, 
Collection<GridCacheContinuousQueryEntry<Object, Object>> entries) {
+        q.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Object, 
Object>>>() {
+            @Override public boolean apply(UUID uuid, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Object, 
Object>> entries) {
                 return true;
             }
         });
@@ -279,8 +279,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
             log,
             new Callable<Object>() {
                 @Override public Object call() throws Exception {
-                    q.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Object, Object>>>() {
-                        @Override public boolean apply(UUID uuid, 
Collection<GridCacheContinuousQueryEntry<Object, Object>> entries) {
+                    q.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Object, 
Object>>>() {
+                        @Override public boolean apply(UUID uuid, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Object, 
Object>> entries) {
                             return false;
                         }
                     });
@@ -358,9 +358,9 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, List<Integer>> map = new HashMap<>();
         final CountDownLatch latch = new CountDownLatch(5);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
             @Override public boolean apply(UUID nodeId,
-                Collection<GridCacheContinuousQueryEntry<Integer, Integer>> 
entries) {
+                
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     synchronized (map) {
                         List<Integer> vals = map.get(e.getKey());
@@ -432,8 +432,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, List<Integer>> map = new HashMap<>();
         final CountDownLatch latch = new CountDownLatch(4);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     synchronized (map) {
                         List<Integer> vals = map.get(e.getKey());
@@ -454,8 +454,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
             }
         });
 
-        qry.remoteFilter(new P1<GridCacheContinuousQueryEntry<Integer, 
Integer>>() {
-            @Override public boolean 
apply(GridCacheContinuousQueryEntry<Integer, Integer> e) {
+        qry.remoteFilter(new 
P1<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>() {
+            @Override public boolean 
apply(org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer> e) {
                 return e.getKey() > 2;
             }
         });
@@ -465,9 +465,9 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
 
         final CountDownLatch latch0 = new CountDownLatch(8);
 
-        qry0.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
+        qry0.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
             @Override public boolean apply(UUID uuid,
-                Collection<GridCacheContinuousQueryEntry<Integer, Integer>> 
entries) {
+                
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> ignored : entries)
                     latch0.countDown();
 
@@ -531,8 +531,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, List<Integer>> map = new HashMap<>();
         final CountDownLatch latch = new CountDownLatch(1);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     synchronized (map) {
                         List<Integer> vals = map.get(e.getKey());
@@ -610,8 +610,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, List<Integer>> map = new HashMap<>();
         final CountDownLatch latch = new CountDownLatch(1);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     synchronized (map) {
                         List<Integer> vals = map.get(e.getKey());
@@ -685,8 +685,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, List<Integer>> map = new HashMap<>();
         final CountDownLatch latch = new CountDownLatch(1);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     synchronized (map) {
                         List<Integer> vals = map.get(e.getKey());
@@ -712,9 +712,9 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
 
         final CountDownLatch latch0 = new CountDownLatch(3);
 
-        qry0.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
+        qry0.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
             @Override public boolean apply(UUID nodeId,
-                Collection<GridCacheContinuousQueryEntry<Integer, Integer>> 
entries) {
+                
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> ignored : entries)
                     latch0.countDown();
 
@@ -763,8 +763,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, List<Integer>> map = new HashMap<>();
         final CountDownLatch latch = new CountDownLatch(5);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     synchronized (map) {
                         List<Integer> vals = map.get(e.getKey());
@@ -856,8 +856,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, List<Integer>> map = new HashMap<>();
         final CountDownLatch latch = new CountDownLatch(5);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     synchronized (map) {
                         List<Integer> vals = map.get(e.getKey());
@@ -940,9 +940,9 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, Integer> map = new ConcurrentHashMap8<>();
         final CountDownLatch latch = new CountDownLatch(10);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
             @Override public boolean apply(UUID nodeId,
-                Collection<GridCacheContinuousQueryEntry<Integer, Integer>> 
entries) {
+                
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     map.put(e.getKey(), e.getValue());
 
@@ -982,8 +982,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, Integer> map = new ConcurrentHashMap8<>();
         final CountDownLatch latch = new CountDownLatch(12);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     map.put(e.getKey(), e.getValue());
 
@@ -1026,8 +1026,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, Integer> map = new ConcurrentHashMap8<>();
         final CountDownLatch latch = new CountDownLatch(10);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     map.put(e.getKey(), e.getValue());
 
@@ -1068,8 +1068,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, Integer> map = new ConcurrentHashMap8<>();
         final CountDownLatch latch = new CountDownLatch(2);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     map.put(e.getKey(), e.getValue());
 
@@ -1080,8 +1080,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
             }
         });
 
-        qry.remoteFilter(new P1<GridCacheContinuousQueryEntry<Integer, 
Integer>>() {
-            @Override public boolean 
apply(GridCacheContinuousQueryEntry<Integer, Integer> e) {
+        qry.remoteFilter(new 
P1<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>() {
+            @Override public boolean 
apply(org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer> e) {
                 return true;
             }
         });
@@ -1123,9 +1123,9 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, Integer> map = new ConcurrentHashMap8<>();
         final CountDownLatch latch = new CountDownLatch(2);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
-                for (GridCacheContinuousQueryEntry<Integer, Integer> e : 
entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
+                for 
(org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, Integer> 
e : entries) {
                     info("Query entry: " + e);
 
                     map.put(e.getKey(), e.getValue());
@@ -1137,8 +1137,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
             }
         });
 
-        qry.remoteFilter(new P1<GridCacheContinuousQueryEntry<Integer, 
Integer>>() {
-            @Override public boolean 
apply(GridCacheContinuousQueryEntry<Integer, Integer> e) {
+        qry.remoteFilter(new 
P1<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>() {
+            @Override public boolean 
apply(org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer> e) {
                 return true;
             }
         });
@@ -1179,8 +1179,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Integer, Integer> map = new ConcurrentHashMap8<>();
         final CountDownLatch latch = new CountDownLatch(2);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 for (Map.Entry<Integer, Integer> e : entries) {
                     map.put(e.getKey(), e.getValue());
 
@@ -1191,8 +1191,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
             }
         });
 
-        qry.remoteFilter(new P1<GridCacheContinuousQueryEntry<Integer, 
Integer>>() {
-            @Override public boolean 
apply(GridCacheContinuousQueryEntry<Integer, Integer> e) {
+        qry.remoteFilter(new 
P1<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>() {
+            @Override public boolean 
apply(org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer> e) {
                 return true;
             }
         });
@@ -1231,9 +1231,9 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Map<Object, Object> map = new ConcurrentHashMap8<>();
         final CountDownLatch latch = new CountDownLatch(2);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Object, Object>>>() {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Object, 
Object>>>() {
             @Override public boolean apply(UUID nodeId,
-                Collection<GridCacheContinuousQueryEntry<Object, Object>> 
entries) {
+                
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Object, 
Object>> entries) {
                 for (Map.Entry<Object, Object> e : entries) {
                     map.put(e.getKey(), e.getValue());
 
@@ -1296,8 +1296,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
 
         final CountDownLatch latch = new CountDownLatch(1);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 latch.countDown();
 
                 return true;
@@ -1325,8 +1325,8 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
         final Collection<Map.Entry<Integer, Integer>> all = new 
ConcurrentLinkedDeque8<>();
         final CountDownLatch latch = new CountDownLatch(2);
 
-        qry.localCallback(new P2<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
-            @Override public boolean apply(UUID nodeId, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>> entries) {
+        qry.localCallback(new P2<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
+            @Override public boolean apply(UUID nodeId, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                 assertEquals(1, entries.size());
 
                 all.addAll(entries);
@@ -1385,9 +1385,9 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
             final CountDownLatch latch = new CountDownLatch(1);
             final Collection<Integer> keys = new GridConcurrentHashSet<>();
 
-            qry.localCallback(new IgniteBiPredicate<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
+            qry.localCallback(new IgniteBiPredicate<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
                 @Override public boolean apply(UUID nodeId,
-                    Collection<GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
+                    
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                     for (Map.Entry<Integer, Integer> e : entries) {
                         keys.add(e.getKey());
 
@@ -1476,15 +1476,15 @@ public abstract class 
GridCacheContinuousQueryAbstractSelfTest extends GridCommo
             GridCache<Integer, Integer> cache = grid(0).cache(null);
 
             try (GridCacheContinuousQuery<Integer, Integer> qry = 
cache.queries().createContinuousQuery()) {
-                qry.localCallback(new IgniteBiPredicate<UUID, 
Collection<GridCacheContinuousQueryEntry<Integer, Integer>>>() {
+                qry.localCallback(new IgniteBiPredicate<UUID, 
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>>>() {
                     @Override public boolean apply(UUID uuid,
-                        Collection<GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
+                        
Collection<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer>> entries) {
                         return true;
                     }
                 });
 
-                qry.remoteFilter(new 
IgnitePredicate<GridCacheContinuousQueryEntry<Integer, Integer>>() {
-                    @Override public boolean 
apply(GridCacheContinuousQueryEntry<Integer, Integer> e) {
+                qry.remoteFilter(new 
IgnitePredicate<org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer,
 Integer>>() {
+                    @Override public boolean 
apply(org.apache.ignite.cache.query.GridCacheContinuousQueryEntry<Integer, 
Integer> e) {
                         return e.getValue() >= 50;
                     }
                 });

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridCacheGgfsPerBlockLruEvictionPolicySelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridCacheGgfsPerBlockLruEvictionPolicySelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridCacheGgfsPerBlockLruEvictionPolicySelfTest.java
index 4dce80d..3e7aa32 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridCacheGgfsPerBlockLruEvictionPolicySelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridCacheGgfsPerBlockLruEvictionPolicySelfTest.java
@@ -19,11 +19,9 @@ package org.gridgain.grid.kernal.processors.ggfs;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
-import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.eviction.ggfs.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.fs.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
@@ -480,7 +478,7 @@ public class GridCacheGgfsPerBlockLruEvictionPolicySelfTest 
extends GridGgfsComm
      * @param curBlocks Current blocks.
      * @param curBytes Current bytes.
      */
-    private void checkEvictionPolicy(final int curBlocks, final long curBytes) 
throws GridInterruptedException {
+    private void checkEvictionPolicy(final int curBlocks, final long curBytes) 
throws IgniteInterruptedException {
         assert GridTestUtils.waitForCondition(new GridAbsPredicate() {
             @Override public boolean apply() {
                 return evictPlc.getCurrentBlocks() == curBlocks && 
evictPlc.getCurrentSize() == curBytes;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAbstractSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAbstractSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAbstractSelfTest.java
index e64fadf..897cad2 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAbstractSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/ggfs/GridGgfsAbstractSelfTest.java
@@ -22,7 +22,6 @@ import org.apache.ignite.cache.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.fs.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
@@ -1142,7 +1141,7 @@ public abstract class GridGgfsAbstractSelfTest extends 
GridGgfsCommonAbstractTes
                         try {
                             U.sleep(10);
                         }
-                        catch (GridInterruptedException ignored) {
+                        catch (IgniteInterruptedException ignored) {
                             // nO-op.
                         }
                     }
@@ -1461,7 +1460,7 @@ public abstract class GridGgfsAbstractSelfTest extends 
GridGgfsCommonAbstractTes
                         try {
                             U.sleep(10);
                         }
-                        catch (GridInterruptedException ignored) {
+                        catch (IgniteInterruptedException ignored) {
                             // nO-op.
                         }
                     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
index 9a67fa3..6568ff6 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/processors/streamer/GridStreamerSelfTest.java
@@ -26,7 +26,6 @@ import org.apache.ignite.resources.*;
 import org.apache.ignite.streamer.*;
 import org.apache.ignite.streamer.router.*;
 import org.apache.ignite.streamer.window.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
@@ -237,7 +236,7 @@ public class GridStreamerSelfTest extends 
GridCommonAbstractTest {
                     try {
                         U.sleep(1000);
                     }
-                    catch (GridInterruptedException ignore) {
+                    catch (IgniteInterruptedException ignore) {
                         // No-op.
                     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/grid/lang/GridTupleSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/lang/GridTupleSelfTest.java 
b/modules/core/src/test/java/org/gridgain/grid/lang/GridTupleSelfTest.java
index 2ecd640..b7239b8 100644
--- a/modules/core/src/test/java/org/gridgain/grid/lang/GridTupleSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/lang/GridTupleSelfTest.java
@@ -17,6 +17,7 @@
 
 package org.gridgain.grid.lang;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.util.lang.*;
@@ -167,12 +168,12 @@ public class GridTupleSelfTest extends 
GridCommonAbstractTest {
     }
 
     /**
-     * Helper method that checks the correctness of {@link GridMetadataAware}
+     * Helper method that checks the correctness of {@link IgniteMetadataAware}
      * implementation.
      *
      * @param ma Metadata aware object.
      */
-    private void checkMetadataAware(GridMetadataAware ma) {
+    private void checkMetadataAware(IgniteMetadataAware ma) {
         // addMeta(name, val).
         assert ma.addMeta("attr1", "val1") == null;
         assert ma.addMeta("attr2", 1) == null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/loadtests/communication/GridIoManagerBenchmark.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/loadtests/communication/GridIoManagerBenchmark.java
 
b/modules/core/src/test/java/org/gridgain/loadtests/communication/GridIoManagerBenchmark.java
index a2d3959..e0b147d 100644
--- 
a/modules/core/src/test/java/org/gridgain/loadtests/communication/GridIoManagerBenchmark.java
+++ 
b/modules/core/src/test/java/org/gridgain/loadtests/communication/GridIoManagerBenchmark.java
@@ -20,7 +20,6 @@ package org.gridgain.loadtests.communication;
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.managers.communication.*;
 import org.gridgain.grid.kernal.managers.discovery.*;
@@ -175,7 +174,7 @@ public class GridIoManagerBenchmark {
                         queries = newQueries;
                     }
                 }
-                catch (GridInterruptedException ignored) {
+                catch (IgniteInterruptedException ignored) {
                     // No-op.
                 }
 
@@ -208,7 +207,7 @@ public class GridIoManagerBenchmark {
         try {
             U.sleep(duration > 0 ? duration * 1000 + WARM_UP_DUR : 
Long.MAX_VALUE);
         }
-        catch (GridInterruptedException ignored) {
+        catch (IgniteInterruptedException ignored) {
             // No-op.
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/loadtests/continuous/GridContinuousOperationsLoadTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/loadtests/continuous/GridContinuousOperationsLoadTest.java
 
b/modules/core/src/test/java/org/gridgain/loadtests/continuous/GridContinuousOperationsLoadTest.java
index 93facb6..2434fea 100644
--- 
a/modules/core/src/test/java/org/gridgain/loadtests/continuous/GridContinuousOperationsLoadTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/loadtests/continuous/GridContinuousOperationsLoadTest.java
@@ -22,7 +22,6 @@ import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.query.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.kernal.processors.cache.query.continuous.*;
 import org.gridgain.grid.util.typedef.*;
@@ -101,7 +100,7 @@ public class GridContinuousOperationsLoadTest {
 
                     qry.callback(new PX2<UUID, Collection<Map.Entry<Object, 
Object>>>() {
                         @Override public boolean applyx(UUID uuid, 
Collection<Map.Entry<Object, Object>> entries)
-                            throws GridInterruptedException {
+                            throws IgniteInterruptedException {
                             if (cbSleepMs > 0)
                                 U.sleep(cbSleepMs);
 
@@ -112,7 +111,7 @@ public class GridContinuousOperationsLoadTest {
                     });
 
                     qry.filter(new PX2<Object, Object>() {
-                        @Override public boolean applyx(Object key, Object 
val) throws GridInterruptedException {
+                        @Override public boolean applyx(Object key, Object 
val) throws IgniteInterruptedException {
                             if (filterSleepMs > 0)
                                 U.sleep(filterSleepMs);
 
@@ -133,7 +132,7 @@ public class GridContinuousOperationsLoadTest {
                         new PX2<UUID, IgniteEvent>() {
                             @Override
                             public boolean applyx(UUID uuid, IgniteEvent evt)
-                                throws GridInterruptedException {
+                                throws IgniteInterruptedException {
                                 if (cbSleepMs > 0)
                                     U.sleep(cbSleepMs);
 
@@ -144,7 +143,7 @@ public class GridContinuousOperationsLoadTest {
                         },
                         new PX1<IgniteEvent>() {
                             @Override
-                            public boolean applyx(IgniteEvent evt) throws 
GridInterruptedException {
+                            public boolean applyx(IgniteEvent evt) throws 
IgniteInterruptedException {
                                 if (filterSleepMs > 0)
                                     U.sleep(filterSleepMs);
 
@@ -173,7 +172,7 @@ public class GridContinuousOperationsLoadTest {
                                 ", updatesPerSec=" + updDelta + ']');
                         }
                     }
-                    catch (GridInterruptedException ignored) {
+                    catch (IgniteInterruptedException ignored) {
                         // No-op.
                     }
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/loadtests/job/GridJobExecutionSingleNodeSemaphoreLoadTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/loadtests/job/GridJobExecutionSingleNodeSemaphoreLoadTest.java
 
b/modules/core/src/test/java/org/gridgain/loadtests/job/GridJobExecutionSingleNodeSemaphoreLoadTest.java
index dee5f71..248e6c9 100644
--- 
a/modules/core/src/test/java/org/gridgain/loadtests/job/GridJobExecutionSingleNodeSemaphoreLoadTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/loadtests/job/GridJobExecutionSingleNodeSemaphoreLoadTest.java
@@ -21,7 +21,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.loadtests.util.*;
@@ -109,7 +108,7 @@ public class GridJobExecutionSingleNodeSemaphoreLoadTest {
                                 avgTasksPerSec.update(curTasksPerSec);
                             }
                         }
-                        catch (GridInterruptedException ignored) {
+                        catch (IgniteInterruptedException ignored) {
                             X.println(">>> Interrupted.");
 
                             Thread.currentThread().interrupt();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
 
b/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
index a2a24cf..9b55e2f 100644
--- 
a/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/loadtests/streamer/GridStreamerIndexLoadTest.java
@@ -23,7 +23,6 @@ import org.apache.ignite.streamer.index.*;
 import org.apache.ignite.streamer.index.hash.*;
 import org.apache.ignite.streamer.index.tree.*;
 import org.apache.ignite.streamer.window.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
@@ -160,7 +159,7 @@ public class GridStreamerIndexLoadTest {
                         prevEvict = curEvict;
                     }
                 }
-                catch (GridInterruptedException ignored) {
+                catch (IgniteInterruptedException ignored) {
                     // No-op.
                 }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/loadtests/streamer/QueryClosure.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/loadtests/streamer/QueryClosure.java 
b/modules/core/src/test/java/org/gridgain/loadtests/streamer/QueryClosure.java
index c0c17b0..0df6c47 100644
--- 
a/modules/core/src/test/java/org/gridgain/loadtests/streamer/QueryClosure.java
+++ 
b/modules/core/src/test/java/org/gridgain/loadtests/streamer/QueryClosure.java
@@ -19,7 +19,6 @@ package org.gridgain.loadtests.streamer;
 
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
@@ -43,7 +42,7 @@ class QueryClosure implements IgniteInClosure<IgniteStreamer> 
{
         try {
             U.sleep(warmup);
         }
-        catch (GridInterruptedException ignore) {
+        catch (IgniteInterruptedException ignore) {
             return;
         }
 
@@ -56,7 +55,7 @@ class QueryClosure implements IgniteInClosure<IgniteStreamer> 
{
             try {
                 U.sleep(SLEEP_PERIOD_SEC * 1000);
             }
-            catch (GridInterruptedException ignore) {
+            catch (IgniteInterruptedException ignore) {
                 return;
             }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/testframework/GridTestSafeThreadFactory.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/testframework/GridTestSafeThreadFactory.java
 
b/modules/core/src/test/java/org/gridgain/testframework/GridTestSafeThreadFactory.java
index 2193ea8..895d11e 100644
--- 
a/modules/core/src/test/java/org/gridgain/testframework/GridTestSafeThreadFactory.java
+++ 
b/modules/core/src/test/java/org/gridgain/testframework/GridTestSafeThreadFactory.java
@@ -18,7 +18,6 @@
 package org.gridgain.testframework;
 
 import org.apache.ignite.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.*;
@@ -157,7 +156,7 @@ public final class GridTestSafeThreadFactory implements 
ThreadFactory {
             for (Thread t : threads)
                 U.join(t);
         }
-        catch (GridInterruptedException ignored) {
+        catch (IgniteInterruptedException ignored) {
             // No-op.
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java 
b/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java
index f87d16a..a5d5de7 100644
--- a/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java
+++ b/modules/core/src/test/java/org/gridgain/testframework/GridTestUtils.java
@@ -24,7 +24,6 @@ import org.apache.ignite.cache.affinity.consistenthash.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.client.ssl.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.dht.*;
@@ -1216,11 +1215,11 @@ public final class GridTestUtils {
      * @param retryInterval Interval between retries in milliseconds.
      * @param c Closure with assertion. All {@link AssertionError}s thrown
      *      from this closure will be ignored {@code retries} times.
-     * @throws GridInterruptedException If interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException If interrupted.
      */
     @SuppressWarnings("ErrorNotRethrown")
     public static void retryAssert(@Nullable IgniteLogger log, int retries, 
long retryInterval, GridAbsClosure c)
-        throws GridInterruptedException {
+        throws IgniteInterruptedException {
         for (int i = 0; i < retries; i++) {
             try {
                 c.apply();
@@ -1273,9 +1272,9 @@ public final class GridTestUtils {
      * @param sleepDur Sleep duration in milliseconds.
      * @param i Integer to increment.
      * @return Incremented value.
      * @throws GridInterruptedException If sleep was interrupted.
interrupted.
      */
-    public static int sleepAndIncrement(int sleepDur, int i) throws 
GridInterruptedException {
+    public static int sleepAndIncrement(int sleepDur, int i) throws 
IgniteInterruptedException {
         U.sleep(sleepDur);
 
         return i + 1;
@@ -1287,9 +1286,9 @@ public final class GridTestUtils {
      * @param cond Condition to wait for.
      * @param timeout Max time to wait in milliseconds.
      * @return {@code true} if condition was achieved, {@code false} otherwise.
-     * @throws GridInterruptedException If interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException If interrupted.
      */
-    public static boolean waitForCondition(GridAbsPredicate cond, long 
timeout) throws GridInterruptedException {
+    public static boolean waitForCondition(GridAbsPredicate cond, long 
timeout) throws IgniteInterruptedException {
         long curTime = U.currentTimeMillis();
         long endTime = curTime + timeout;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/core/src/test/java/org/gridgain/testsuites/bamboo/GridDataGridTestSuite.java
----------------------------------------------------------------------
@@ -1273,9 +1272,9 @@ public final class GridTestUtils {
      * @param i Integer to increment.
      * @return Incremented value.
-     * @throws GridInterruptedException If sleep was interrupted.
+     * @throws org.apache.ignite.IgniteInterruptedException If sleep was 
interrupted.
      */
diff --git 
a/modules/core/src/test/java/org/gridgain/testsuites/bamboo/GridDataGridTestSuite.java
 
b/modules/core/src/test/java/org/gridgain/testsuites/bamboo/GridDataGridTestSuite.java
index a4de1f9..bcf1c2b 100644
--- 
a/modules/core/src/test/java/org/gridgain/testsuites/bamboo/GridDataGridTestSuite.java
+++ 
b/modules/core/src/test/java/org/gridgain/testsuites/bamboo/GridDataGridTestSuite.java
@@ -22,9 +22,9 @@ import org.apache.ignite.internal.processors.cache.*;
 import org.apache.ignite.internal.processors.cache.expiry.*;
 import org.apache.ignite.internal.processors.cache.integration.*;
 import org.gridgain.grid.*;
+import org.apache.ignite.cache.store.jdbc.*;
 import org.gridgain.grid.cache.affinity.fair.*;
 import org.gridgain.grid.cache.store.*;
-import org.apache.ignite.cache.store.jdbc.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.dht.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
----------------------------------------------------------------------
diff --git 
a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
 
b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
index 2d89999..379eb94 100644
--- 
a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
+++ 
b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridCacheDeploymentTestTask1.java
@@ -22,7 +22,6 @@ import org.apache.ignite.cache.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.cache.*;
 import org.gridgain.grid.util.typedef.*;
 import org.jetbrains.annotations.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityFunction.java
----------------------------------------------------------------------
diff --git 
a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityFunction.java
 
b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityFunction.java
index cc01a10..8c4223c 100644
--- 
a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityFunction.java
+++ 
b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityFunction.java
@@ -19,7 +19,6 @@ package org.gridgain.grid.tests.p2p;
 
 import org.apache.ignite.cache.affinity.*;
 import org.apache.ignite.cluster.*;
-import org.gridgain.grid.cache.affinity.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityKeyMapper.java
----------------------------------------------------------------------
diff --git 
a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityKeyMapper.java
 
b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityKeyMapper.java
index d621575..9823795 100644
--- 
a/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityKeyMapper.java
+++ 
b/modules/extdata/p2p/src/main/java/org/gridgain/grid/tests/p2p/GridExternalAffinityKeyMapper.java
@@ -18,7 +18,6 @@
 package org.gridgain.grid.tests.p2p;
 
 import org.apache.ignite.cache.affinity.*;
-import org.gridgain.grid.cache.affinity.*;
 
 /**
  * Test mapper for P2P class loading tests.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/extdata/uri/src/main/java/org/apache/ignite/spi/deployment/uri/tasks/GridUriDeploymentAbstractTestTask.java
----------------------------------------------------------------------
diff --git 
a/modules/extdata/uri/src/main/java/org/apache/ignite/spi/deployment/uri/tasks/GridUriDeploymentAbstractTestTask.java
 
b/modules/extdata/uri/src/main/java/org/apache/ignite/spi/deployment/uri/tasks/GridUriDeploymentAbstractTestTask.java
index 48a17a6..90a795f 100644
--- 
a/modules/extdata/uri/src/main/java/org/apache/ignite/spi/deployment/uri/tasks/GridUriDeploymentAbstractTestTask.java
+++ 
b/modules/extdata/uri/src/main/java/org/apache/ignite/spi/deployment/uri/tasks/GridUriDeploymentAbstractTestTask.java
@@ -19,7 +19,6 @@ package org.apache.ignite.spi.deployment.uri.tasks;
 
 import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
-import org.gridgain.grid.*;
 
 import java.util.*;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/hadoop/src/main/java/org/gridgain/grid/kernal/ggfs/hadoop/GridGgfsHadoopIpcIo.java
----------------------------------------------------------------------
diff --git 
a/modules/hadoop/src/main/java/org/gridgain/grid/kernal/ggfs/hadoop/GridGgfsHadoopIpcIo.java
 
b/modules/hadoop/src/main/java/org/gridgain/grid/kernal/ggfs/hadoop/GridGgfsHadoopIpcIo.java
index 5d71c81..318a411 100644
--- 
a/modules/hadoop/src/main/java/org/gridgain/grid/kernal/ggfs/hadoop/GridGgfsHadoopIpcIo.java
+++ 
b/modules/hadoop/src/main/java/org/gridgain/grid/kernal/ggfs/hadoop/GridGgfsHadoopIpcIo.java
@@ -19,7 +19,6 @@ package org.gridgain.grid.kernal.ggfs.hadoop;
 
 import org.apache.commons.logging.*;
 import org.apache.ignite.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.ggfs.common.*;
 import org.gridgain.grid.util.*;
@@ -279,7 +278,7 @@ public class GridGgfsHadoopIpcIo implements 
GridGgfsHadoopIo {
 
                 reader = null;
             }
-            catch (GridInterruptedException ignored) {
+            catch (IgniteInterruptedException ignored) {
                 Thread.currentThread().interrupt();
 
                 log.warn("Got interrupted while waiting for reader thread to 
shut down (will return).");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/jobtracker/GridHadoopJobTracker.java
----------------------------------------------------------------------
diff --git 
a/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/jobtracker/GridHadoopJobTracker.java
 
b/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/jobtracker/GridHadoopJobTracker.java
index c08d15d..bf6df53 100644
--- 
a/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/jobtracker/GridHadoopJobTracker.java
+++ 
b/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/jobtracker/GridHadoopJobTracker.java
@@ -22,7 +22,6 @@ import org.apache.ignite.cache.*;
 import org.apache.ignite.cache.query.*;
 import org.apache.ignite.events.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.cache.*;
 import org.apache.ignite.hadoop.*;
 import org.gridgain.grid.kernal.managers.eventstorage.*;
 import org.gridgain.grid.kernal.processors.cache.*;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/shuffle/GridHadoopShuffleJob.java
----------------------------------------------------------------------
diff --git 
a/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/shuffle/GridHadoopShuffleJob.java
 
b/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/shuffle/GridHadoopShuffleJob.java
index 1ada8b6..c66e863 100644
--- 
a/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/shuffle/GridHadoopShuffleJob.java
+++ 
b/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/shuffle/GridHadoopShuffleJob.java
@@ -20,7 +20,6 @@ package org.gridgain.grid.kernal.processors.hadoop.shuffle;
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.thread.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.hadoop.*;
 import org.gridgain.grid.kernal.processors.hadoop.counter.*;
 import org.gridgain.grid.kernal.processors.hadoop.shuffle.collections.*;
@@ -411,7 +410,7 @@ public class GridHadoopShuffleJob<T> implements 
AutoCloseable {
                 snd.join();
             }
             catch (InterruptedException e) {
-                throw new GridInterruptedException(e);
+                throw new IgniteInterruptedException(e);
             }
         }
 
@@ -460,7 +459,7 @@ public class GridHadoopShuffleJob<T> implements 
AutoCloseable {
                     log.debug("Finished waiting for sending thread to complete 
on shuffle job flush: " + job.id());
             }
             catch (InterruptedException e) {
-                throw new GridInterruptedException(e);
+                throw new IgniteInterruptedException(e);
             }
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/550d6033/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/taskexecutor/GridHadoopExecutorService.java
----------------------------------------------------------------------
diff --git 
a/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/taskexecutor/GridHadoopExecutorService.java
 
b/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/taskexecutor/GridHadoopExecutorService.java
index 345915f..246ef4f 100644
--- 
a/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/taskexecutor/GridHadoopExecutorService.java
+++ 
b/modules/hadoop/src/main/java/org/gridgain/grid/kernal/processors/hadoop/taskexecutor/GridHadoopExecutorService.java
@@ -20,7 +20,6 @@ package 
org.gridgain.grid.kernal.processors.hadoop.taskexecutor;
 
 import org.apache.ignite.*;
 import org.apache.ignite.thread.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.hadoop.*;
 import org.gridgain.grid.util.worker.*;
 import org.jdk8.backport.*;
@@ -179,7 +178,7 @@ public class GridHadoopExecutorService {
             workerName = task.toString();
 
         GridWorker w = new GridWorker(gridName, workerName, log, lsnr) {
-            @Override protected void body() throws InterruptedException, 
GridInterruptedException {
+            @Override protected void body() throws InterruptedException, 
IgniteInterruptedException {
                 try {
                     task.call();
                 }

Reply via email to